#
# spec file for package rdesktop
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rdesktop
Version:        1.8.3
Release:        lp151.1.1
Summary:        A Remote Desktop Protocol client
License:        GPL-3.0+
Group:          Productivity/Networking/Other
Url:            http://www.rdesktop.org/
Source:         http://prdownloads.sourceforge.net/rdesktop/%{name}-%{version}.tar.gz
## FIX-openSUSE: remove "Don't depend on pkg-config"
Patch0:         rdesktop-fix_pkgconfig_check.patch
# PATCH-FIX-UPSTREAM rdesktop-Fix-OpenSSL-1.1-compability-issues.patch
Patch1:         rdesktop-Fix-OpenSSL-1.1-compability-issues.patch
# PATCH-FIX-UPSTREAM rdesktop-Fix-crash-in-rdssl_cert_to_rkey.patch
Patch2:         rdesktop-Fix-crash-in-rdssl_cert_to_rkey.patch
# PATCH-FIX-OPENSUSE rdesktop-Fix-keymap-script.patch
Patch3:         rdesktop-Fix-keymap-script.patch
Patch4:         rdesktop-Fix-key-caching.patch
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libgssglue-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
rdesktop is an open source client for Windows NT Terminal Server and
Windows 2000 Terminal Services, capable of natively speaking Remote
Desktop Protocol (RDP) in order to present the user's NT desktop.
Unlike Citrix ICA, no server extensions are required.

%prep
%setup -q
%patch0
%if 0%{?suse_version} > 1110
%patch1 -p1
%patch2 -p1
%patch4 -p1
%endif
%patch3 -p1

## rpmlint
# incorrect-fsf-address /usr/share/rdesktop/keymaps/convert-map
perl -p -i -e 's|^# Foundation.*|# Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA|' keymaps/convert-map

%build
autoreconf -fiv
CFLAGS="%{optflags} -fno-strict-aliasing" \
%configure \
  --enable-smartcard \
  --with-openssl=%{_prefix} \
  --with-ipv6
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} STRIP=true install
make DESTDIR=%{buildroot} installman
mkdir -p %{buildroot}%{_datadir}/rdesktop
cp -r keymaps %{buildroot}%{_datadir}/rdesktop
chmod -R a+r %{buildroot}%{_datadir}/rdesktop/keymaps

%files
%defattr(-,root,root,755)
%doc COPYING doc README
%{_bindir}/rdesktop
%{_datadir}/rdesktop
%{_mandir}/man1/rdesktop.1.gz

%changelog
* Mon Feb 12 2018 markus.beth@web.de
- Added rdesktop-Fix-key-caching.patch
  backport of https://github.com/rdesktop/rdesktop/commit/a3dfceefc2c729243b71270e3f503fa2dd57ec8d
* Sat Feb  3 2018 aloisio@gmx.com
- Added rdesktop-Fix-OpenSSL-1.1-compability-issues.patch
  and rdesktop-Fix-crash-in-rdssl_cert_to_rkey.patch to fix
  Factory build
- Added rdesktop-Fix-keymap-script.patch
* Mon Aug 10 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Mon Dec 29 2014 chris@computersalat.de
- fix for boo#897205 (rdesktop to Windows 2008 R2 Terminal Server)
- update to 1.8.3
  * Added a persistent mode used with SeamlessRDP
  * Added US international keyboard layout with dead keys
  * Code cleanup to match specifications, use constants defined
    instead of magic numbers, remove of dead code
  * Fix regression with failed connection and a invalid licensing
    message, introduced in 1.8.2
  * Fix issue with Non ASCII user / password when using CredSSP
  * Fix issues using smartcard redirection with Windows 2012 R2
  * Fix issue with windows key functionality
  * Fix memory corruption when using rdp_out_unistr()
  * Fix workaround for the lack of support for alpha cursors
  * Fix silent exit when redirected when using CredSSP
  * Fix crash when starting rdesktop without domain specified while
    using CredSSP
  * Fix issue in SeamlessRDP protocol parser upon reconnect
  * Fix issue were a new SeamlessRDP application is respawned upon
    a reconnection
* Thu Oct  2 2014 crrodriguez@opensuse.org
- Enable libao backend, this will help with pulseaudio
- Do not buildrequire xorg-x11-devel just the specific needed
  X libraries
* Sun Jun  1 2014 chris@computersalat.de
- update to 1.8.2
  * Support enhanced server redirection (Session broker 2012)
  * Support License Error Alert PDU
  * Changed default driver for printer redirection
  * Fix CredSSP login using non-ASCII username/password
  * Fix double login prompt bug with Win2008 server redirection
  * Fix keysym collisions
  * Fix mouse cursor with 2012 R2
  * Fix local drive redirection with Win8 / Win2012
  * Fix issue with mouse cursor hotspot
  * Fix issue with mouse / keyboard against VirtualBox RDP
  * Fix uncomplete czech keymap * Fix error in dutch keymap
* Wed Nov 27 2013 chris@computersalat.de
- update to 1.8.1
  * Fix a typo in configure.ac
  * Fix a bug which made rdesktop steal CPU cycles.
  * Fix issue with reconnect, make use of deactivate variable
  * Added 4 new disconnect reasons with exit codes
  * Fix issues of window handling in SeamlessRDP parts of rdesktop
  * Fix a backward compability with OpenSSL < 0.9.9
  * Fix a bug when code needs a x window available but there are none.
  * Fix a sigsegv zeroing memory
  * Fix a 64bit portability issue
- remove obsolete patches
  * tcp_return, 64bit_portability_issue
* Mon Aug 12 2013 chris@computersalat.de
- fix for sf#366: http://sourceforge.net/p/rdesktop/bugs/366/
  * added patches: tcp_return, 64bit_portability_issue
* Sat Aug 10 2013 chris@computersalat.de
- update to 1.8.0
  * Support for protocol negotiation eg. SSL/TLSv1 and CredSSP
  * Support for CredSSP + Kerberos authentication (NLA)
  * Support for smart card single-sign-on
  * Support passing smart card pin as password as argument
  * Added IPC for controlling a master rdesktop process
  * Support for connection sharing when using SeamlessRDP
  * Improved handling of network connection failures
  * Autoreconnect using the connection cookie at network failure
  * Fix a few smart card issues
  * Fix bug with mouse scroll handling
  * Fix for left/right braces in Italian keymap
  * Fix crash and memory leak in local drive redirection
  * Fixes issues with license files loading/saving
- remove obsolete rdesktop-1.7.0-lib64.dif patch
- add missing dependency for libgssglue
* Tue Feb 19 2013 alexandre@exatati.com.br
- Enable smartcard support.
* Sat Jan 12 2013 coolo@suse.com
- remove suse_update_config
* Wed Feb 22 2012 chris@computersalat.de
- update to version rdesktop (1.7.1)
  * Fix clipboard issue when not building with unicode support
  * Fix compilation against newer PCSC lite versions
  * Fix for per-device license mode on Windows 2008 R2 terminal server
  * Fix building 64bit version with static openssl linkage
  * Rewrite of smartcard handling for 64bit support, fixes several bugs
  * Improved license handling using XDG directories
- fix rpmlint
  * incorrect-fsf-address
  * non-standard-group
- remove obsolete patch
  * lib64 patch
- rebase fix_pkgconfig_check patch
* Fri Jan  6 2012 sweet_f_a@gmx.de
- enable ipv6 support
- remove unused patches
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Apr 28 2011 claes.backstrom@opensuse.org
- update to version 1.7.0
  * Security: Directory traversal vulnerability with disk
    redirection (disallow /.. requests)
  * New maintainer: Peter Åstrand from Cendio
  * Brush cache support
  * Removed the hardcoded limit of the username length
  * Increased domain name length to 255 chars
  * Improved compatibility with PulseAudio/padsp
  * Cleaned up and documented the return values
  * Keyboard fix: avoid stuck keys in certain cases
  * Support for new pointers
  * License has been changed to GPLv3
  * EWMH fixes for 64-bit machines
  * RandR support: automatically resize session if using relative screen size
  * Improved support for Windows 2008 Session Broker
  * Japanese keyboard map has been improved
  * New keyboard map: fr-bepo
  * Many stability fixes regarding smart card redirection
  * Windows 2008 R2 / 7: Fix sound playback when not using other redirections
  * Windows 2008 R2 / 7: Solve disk redirection read-only issues
  * Windows 2008 R2 / 7: Solve issue with recursive deletion
  * Avoid exit when printing, if lpr command terminates early
- updated rdesktop-1.4.0-lib64.dif -> rdesktop-1.7.0-lib64.dif
- remove obsolete patches
  * rdesktop-1.5.0-fix-printer-strcmp.dif
  * rdesktop-NOMAD.dif
* Wed Feb  4 2009 davidr@novell.com
- Better detection of fullscreen dimensions when no window manager
  is running. (bnc#456172)
* Fri Nov 21 2008 davidr@novell.com
- Fix resize restriction issue in NOMAD patch.
- Fix background color typo.
- Fix annoying keyboard grabbing issue.
* Tue Nov 11 2008 davidr@novell.com
- Fix DMX input focus handling.
* Wed Oct 15 2008 davidr@novell.com
- Don't prevent DMX DnD support from working properly.
- Fix handling of special keys when using the rdpx11 channel.
- Disable old fs fix. NOMAD patch includes a much better fullscreen
  fix that actually works.
- Fix blocking issues in x11 forwarding and make x11 stream
  compression work properly.
- Fix issue with grabbing of the keyboard and preventing events
  from being forwarded when rdpx11 channel is used.
* Wed Sep 17 2008 mc@suse.de
- add NOMAD patch (for FATE 304243, 304244, 304246)
* Wed Jun 18 2008 mc@suse.de
- update to version 1.6.0
  * Fix for crash with recent versions of X.Org
  * Fix for potential vulnerability against compromised/malicious servers (reported by iDefense)
  * Fix for Windows 2008 Server
  * ALSA driver added
  * Sound drivers can now be selected at runtime
  * Smartcard support (Alexi Volkov <alexi@myrealbox.com>)
  * Send physical mouse buttons rather than logical ones
- remove obsolete patches
* Thu May  8 2008 mc@suse.de
- fix multiple problems in rdesktop
  * CVE-2008-1801 - integer underflow vulnerability
  * CVE-2008-1802 - BSS overflow vulnerability
  * CVE-2008-1803 - integer signedness vulnerability
* Wed Apr 25 2007 mc@suse.de
- fix segfaults after recent update of X.org
  [#267016]
* Tue Dec 19 2006 mc@suse.de
- fix "comparison with string literal" [#228709]
* Mon Nov  6 2006 schwab@suse.de
- Don't strip binaries.
* Tue Sep 19 2006 mc@suse.de
- rdesktop (1.5.0)
  * SeamlessRDP - seamless windows support
  * Keymap fixes
  * Fix connection issues with Windows XP RTM
  * Keyboard handling improvements and fixes
  * SGI/Irix sound-driver fixes
  * Support for clipboard INCR protocol
  * Session Directory support
  * Support for long filenames on redirected drives
  * XOR ellipse drawing fix
  * Clipboard unicode support
  * Fix display issues with exotic color depths (30bpp, 32bpp, etc)
  * Large file support
  * The default color depth is now the depth of the root window
  * Basic support for Windows Vista Beta 2
  * Fix high cpu-usage in OSS-driver
* Mon Sep 11 2006 mc@suse.de
- /usr/X11R6 => /usr/
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Thu May  4 2006 mc@suse.de
- add xgl fix [#164671]
* Mon Mar 20 2006 mc@suse.de
- fix Compiz makes rdesktop window entirely transparent
  [# 155335]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun  3 2005 mc@suse.de
- switch to version 1.4.1
  * persistent bitmap cache optimisations
  * support for more RDP-orders (ellipse, polygon)
  * libao sound-driver (for Mac OSX and others)
  * Unicode support for transmitted strings/filenames
  * Added korean keymap
  * Xembed fixes to work with krdc correctly
  * Portability fixes
  * Support for RDP-compression (all bpps)
  * process RDP recv queue if send queue is full (Debian bug #246461)
  * SGI/Irix sound-driver fixes
* Wed Mar 30 2005 mc@suse.de
- switch to version 1.4.0
- remove rdesktop-1.2.0-24bit-color.dif, rdesktop-1.2.0-configure.dif
  and rdesktop-kdehead.patch
- add rdesktop-1.4.0-lib64.dif
* Tue Aug 24 2004 mc@suse.de
- add rdesktop-kdehead.patch to make krdc working
  [#43860]
* Thu Feb 26 2004 mc@suse.de
- switch to version 1.3.1
  * Crypto fixes for RDP5
  * Keyboard and keymap fixes
  * some endianess fixes for high color
  * portability enhancements
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Oct 30 2003 mc@suse.de
- switch to version 1.3.0
* Mon Aug 18 2003 mc@suse.de
- renamed rdesktop-1.2.0.dif to rdesktop-1.2.0-24bit-color.dif
- add rdesktop-1.2.0-configure.dif . Makes it possible to set
  CFLAGS from external.
- add -fno-strict-aliasing
- removed unused patches
  (rdesktop-unified-patch19-9-0.bz2, rdesktop-1.1.0.dif)
* Fri Jul  4 2003 sndirsch@suse.de
- workaround for 24bit color depth problem (Bug #27726)
* Mon Jun 16 2003 coolo@suse.de
- use BuildRoot
* Tue Mar 18 2003 sndirsch@suse.de
- added missing keymaps (Bug #25565)
* Thu Jan 30 2003 sndirsch@suse.de
- updated to release 1.2.0 (Bug #23211)
  * this features new keyboard mapping code, high encryption support
    and many small additions and bugfixes
* Fri Aug 23 2002 uli@suse.de
- added patches from http://bibl4.oru.se/projects/rdesktop
  that have been reported to be necessary for proper operation
  (bug #18223)
* Wed Apr 24 2002 uli@suse.de
- fixed for lib64
* Thu Oct 18 2001 uli@suse.de
- initial package
